@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package Dist::Iller;
 
 # ABSTRACT: A Dist::Zilla & Pod::Weaver preprocessor
-our $VERSION = '0.1404';
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1405';
 
 use Dist::Iller::Elk;
 use Types::Standard qw/Map Str ConsumerOf/;
@@ -39,9 +40,11 @@ has filepath => (
 
 sub parse {
     my $self = shift;
+    my $phase = shift;
 
     my $yaml = YAML::Tiny->read($self->filepath->stringify);
 
+    DOCTYPE:
     for my $document (sort { $a->{'doctype'} cmp $b->{'doctype'} } @{ $yaml }) {
         my $doctype_class = sprintf 'Dist::Iller::DocType::%s', camelize($document->{'doctype'});
         try {
@@ -50,7 +53,7 @@ sub parse {
         catch {
             croak "Can't load $doctype_class: $_";
         };
-
+        next DOCTYPE if $doctype_class->phase ne $phase;
         $self->set_doc($document->{'doctype'}, $doctype_class->new->parse($document));
     }
     if($self->get_doc('dist')) {
@@ -118,20 +121,20 @@ Dist::Iller - A Dist::Zilla & Pod::Weaver preprocessor
 
 =begin HTML
 
-<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-83.8%-orange.svg" alt="coverage 83.8%" /></p>
+<p><img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-84.3%-orange.svg" alt="coverage 84.3%" /></p>
 
 =end HTML
 
 
 =begin markdown
 
-![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller) ![coverage 83.8%](https://img.shields.io/badge/coverage-83.8%-orange.svg)
+![Requires Perl 5.10+](https://img.shields.io/badge/perl-5.10+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller) ![coverage 84.3%](https://img.shields.io/badge/coverage-84.3%-orange.svg)
 
 =end markdown
 
 =head1 VERSION
 
-Version 0.1404, released 2016-02-11.
+Version 0.1405, released 2016-02-15.
 
 =head1 SYNOPSIS
 
